@@ -40,7 +40,7 @@
  * #GdkEventKey structure, which is passed to signal handlers for the
  * #GtkWidget::key-press-event and #GtkWidget::key-release-event signals.
  * The complete list of key values can be found in the
- * `gdk/gdkkeysyms.h` header file.
+ * <filename>&lt;gdk/gdkkeysyms.h&gt;</filename> header file.
  *
  * Key values are regularly updated from the upstream X.org X11 implementation,
  * so new values are added regularly. They will be prefixed with GDK_KEY_ rather
@@ -57,8 +57,7 @@
  * When it makes sense, key values can be converted to and from
  * Unicode characters with gdk_keyval_to_unicode() and gdk_unicode_to_keyval().
  *
- * # Groups # {#key-group-explanation}
- *
+ * <para id="key-group-explanation">
  * One #GdkKeymap object exists for each user display. gdk_keymap_get_default()
  * returns the #GdkKeymap for the default display; to obtain keymaps for other
  * displays, use gdk_keymap_get_for_display(). A keymap
@@ -66,10 +65,10 @@
  * as a representation of a symbol printed on a physical keyboard key. That is, it
  * contains three pieces of information. First, it contains the hardware keycode;
  * this is an identifying number for a physical key. Second, it contains the
- * “level” of the key. The level indicates which symbol on the
+ * <firstterm>level</firstterm> of the key. The level indicates which symbol on the
  * key will be used, in a vertical direction. So on a standard US keyboard, the key
- * with the number “1“ on it also has the exclamation point (”!”) character on
- * it. The level indicates whether to use the “1” or the “!” symbol.  The letter
+ * with the number "1" on it also has the exclamation point ("!") character on
+ * it. The level indicates whether to use the "1" or the "!" symbol.  The letter
  * keys are considered to have a lowercase letter at level 0, and an uppercase
  * letter at level 1, though only the uppercase letter is printed.  Third, the
  * #GdkKeymapKey contains a group; groups are not used on standard US keyboards,
@@ -79,15 +78,16 @@
  * group 0, a key might have two English characters, and in group 1 it might have
  * two Hebrew characters. The Hebrew characters will be printed on the key next to
  * the English characters.
+ * </para>
  *
- * In order to use a keymap to interpret a key event, it’s necessary to first
+ * In order to use a keymap to interpret a key event, it's necessary to first
  * convert the keyboard state into an effective group and level. This is done via a
  * set of rules that varies widely according to type of keyboard and user
  * configuration. The function gdk_keymap_translate_keyboard_state() accepts a
  * keyboard state -- consisting of hardware keycode pressed, active modifiers, and
  * active group -- applies the appropriate rules, and returns the group/level to be
  * used to index the keymap, along with the modifiers which did not affect the
- * group and level. i.e. it returns “unconsumed modifiers.” The keyboard group may
+ * group and level. i.e. it returns "unconsumed modifiers." The keyboard group may
  * differ from the effective group used for keymap lookups because some keys don't
  * have multiple groups - e.g. the Enter key is always in group 0 regardless of
  * keyboard state.
@@ -95,7 +95,7 @@
  * Note that gdk_keymap_translate_keyboard_state() also returns the keyval, i.e. it
  * goes ahead and performs the keymap lookup in addition to telling you which
  * effective group/level values were used for the lookup. #GdkEventKey already
- * contains this keyval, however, so you don’t normally need to call
+ * contains this keyval, however, so you don't normally need to call
  * gdk_keymap_translate_keyboard_state() just to get the keyval.
  */
 
@@ -133,12 +133,12 @@ gdk_keymap_class_init (GdkKeymapClass *klass)
    * Since: 2.0
    */
   signals[DIRECTION_CHANGED] =
-    g_signal_new (g_intern_static_string ("direction-changed"),
+    g_signal_new ("direction-changed",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GdkKeymapClass, direction_changed),
 		  NULL, NULL,
-		  NULL,
+		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE,
 		  0);
   /**
@@ -151,12 +151,12 @@ gdk_keymap_class_init (GdkKeymapClass *klass)
    * Since: 2.2
    */
   signals[KEYS_CHANGED] =
-    g_signal_new (g_intern_static_string ("keys-changed"),
+    g_signal_new ("keys-changed",
 		  G_OBJECT_CLASS_TYPE (object_class),
 		  G_SIGNAL_RUN_LAST,
 		  G_STRUCT_OFFSET (GdkKeymapClass, keys_changed),
 		  NULL, NULL,
-		  NULL,
+		  g_cclosure_marshal_VOID__VOID,
 		  G_TYPE_NONE,
 		  0);
 
@@ -171,12 +171,12 @@ gdk_keymap_class_init (GdkKeymapClass *klass)
    * Since: 2.16
    */
   signals[STATE_CHANGED] =
-    g_signal_new (g_intern_static_string ("state_changed"),
+    g_signal_new ("state_changed",
                   G_OBJECT_CLASS_TYPE (object_class),
                   G_SIGNAL_RUN_LAST,
                   G_STRUCT_OFFSET (GdkKeymapClass, state_changed),
                   NULL, NULL,
-                  NULL,
+                  g_cclosure_marshal_VOID__VOID,
                   G_TYPE_NONE,
                   0);
 }
@@ -189,6 +189,25 @@ gdk_keymap_init (GdkKeymap *keymap)
 /* Other key-handling stuff
  */
 
+/**
+ * gdk_keyval_convert_case:
+ * @symbol: a keyval
+ * @lower: (out): return location for lowercase version of @symbol
+ * @upper: (out): return location for uppercase version of @symbol
+ *
+ * Obtains the upper- and lower-case versions of the keyval @symbol.
+ * Examples of keyvals are #GDK_KEY_a, #GDK_KEY_Enter, #GDK_KEY_F1, etc.
+ */
+void
+gdk_keyval_convert_case (guint symbol,
+                         guint *lower,
+                         guint *upper)
+{
+  GdkDisplayManager *manager = gdk_display_manager_get ();
+
+  GDK_DISPLAY_MANAGER_GET_CLASS (manager)->keyval_convert_case (manager, symbol, lower, upper);
+}
+
 /**
  * gdk_keyval_to_upper:
  * @keyval: a key value.
@@ -277,8 +296,6 @@ gdk_keyval_is_lower (guint keyval)
  * Returns the #GdkKeymap attached to the default display.
  *
  * Returns: (transfer none): the #GdkKeymap attached to the default display.
- *
- * Deprecated: 3.22: Use gdk_keymap_get_for_display() instead
  */
 GdkKeymap*
 gdk_keymap_get_default (void)
@@ -359,24 +376,6 @@ gdk_keymap_get_num_lock_state (GdkKeymap *keymap)
   return GDK_KEYMAP_GET_CLASS (keymap)->get_num_lock_state (keymap);
 }
 
-/**
- * gdk_keymap_get_scroll_lock_state:
- * @keymap: a #GdkKeymap
- *
- * Returns whether the Scroll Lock modifer is locked.
- *
- * Returns: %TRUE if Scroll Lock is on
- *
- * Since: 3.18
- */
-gboolean
-gdk_keymap_get_scroll_lock_state (GdkKeymap *keymap)
-{
-  g_return_val_if_fail (GDK_IS_KEYMAP (keymap), FALSE);
-
-  return GDK_KEYMAP_GET_CLASS (keymap)->get_scroll_lock_state (keymap);
-}
-
 /**
  * gdk_keymap_get_modifier_state:
  * @keymap: a #GdkKeymap
@@ -401,7 +400,7 @@ gdk_keymap_get_modifier_state (GdkKeymap *keymap)
 /**
  * gdk_keymap_get_entries_for_keyval:
  * @keymap: a #GdkKeymap
- * @keyval: a keyval, such as %GDK_KEY_a, %GDK_KEY_Up, %GDK_KEY_Return, etc.
+ * @keyval: a keyval, such as %GDK_a, %GDK_Up, %GDK_Return, etc.
  * @keys: (out) (array length=n_keys) (transfer full): return location
  *     for an array of #GdkKeymapKey
  * @n_keys: return location for number of elements in returned array
@@ -418,7 +417,7 @@ gdk_keymap_get_modifier_state (GdkKeymap *keymap)
  * The returned array should be freed
  * with g_free().
  *
- * Returns: %TRUE if keys were found and returned
+ * Return value: %TRUE if keys were found and returned
  **/
 gboolean
 gdk_keymap_get_entries_for_keyval (GdkKeymap     *keymap,
@@ -439,9 +438,9 @@ gdk_keymap_get_entries_for_keyval (GdkKeymap     *keymap,
  * gdk_keymap_get_entries_for_keycode:
  * @keymap: a #GdkKeymap
  * @hardware_keycode: a keycode
- * @keys: (out) (array length=n_entries) (transfer full) (optional): return
+ * @keys: (out) (array length=n_entries) (transfer full): return
  *     location for array of #GdkKeymapKey, or %NULL
- * @keyvals: (out) (array length=n_entries) (transfer full) (optional): return
+ * @keyvals: (out) (array length=n_entries) (transfer full): return
  *     location for array of keyvals, or %NULL
  * @n_entries: length of @keys and @keyvals
  *
@@ -479,7 +478,7 @@ gdk_keymap_get_entries_for_keycode (GdkKeymap     *keymap,
  * this function, since the effective group/level may not be
  * the same as the current keyboard state.
  *
- * Returns: a keyval, or 0 if none was mapped to the given @key
+ * Return value: a keyval, or 0 if none was mapped to the given @key
  **/
 guint
 gdk_keymap_lookup_key (GdkKeymap          *keymap,
@@ -508,51 +507,57 @@ gdk_keymap_lookup_key (GdkKeymap          *keymap,
  * group, and level. Modifiers that affected the translation and
  * are thus unavailable for application use are returned in
  * @consumed_modifiers.
- * See [Groups][key-group-explanation] for an explanation of
+ * See <xref linkend="key-group-explanation"/> for an explanation of
  * groups and levels. The @effective_group is the group that was
  * actually used for the translation; some keys such as Enter are not
  * affected by the active keyboard group. The @level is derived from
  * @state. For convenience, #GdkEventKey already contains the translated
- * keyval, so this function isn’t as useful as you might think.
+ * keyval, so this function isn't as useful as you might think.
  *
- * @consumed_modifiers gives modifiers that should be masked outfrom @state
- * when comparing this key press to a hot key. For instance, on a US keyboard,
- * the `plus` symbol is shifted, so when comparing a key press to a
- * `<Control>plus` accelerator `<Shift>` should be masked out.
- *
- * |[<!-- language="C" -->
- * // We want to ignore irrelevant modifiers like ScrollLock
- * #define ALL_ACCELS_MASK (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK)
+ * <note><para>
+ * @consumed_modifiers gives modifiers that should be masked out
+ * from @state when comparing this key press to a hot key. For
+ * instance, on a US keyboard, the <literal>plus</literal>
+ * symbol is shifted, so when comparing a key press to a
+ * <literal>&lt;Control&gt;plus</literal> accelerator &lt;Shift&gt; should
+ * be masked out.
+ * </para>
+ * <informalexample><programlisting>
+ * &sol;* We want to ignore irrelevant modifiers like ScrollLock *&sol;
+ * &num;define ALL_ACCELS_MASK (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK)
  * gdk_keymap_translate_keyboard_state (keymap, event->hardware_keycode,
  *                                      event->state, event->group,
- *                                      &keyval, NULL, NULL, &consumed);
+ *                                      &amp;keyval, NULL, NULL, &amp;consumed);
  * if (keyval == GDK_PLUS &&
- *     (event->state & ~consumed & ALL_ACCELS_MASK) == GDK_CONTROL_MASK)
- *   // Control was pressed
- * ]|
- * 
+ *     (event->state &amp; ~consumed &amp; ALL_ACCELS_MASK) == GDK_CONTROL_MASK)
+ *   &sol;* Control was pressed *&sol;
+ * </programlisting></informalexample>
+ * <para>
  * An older interpretation @consumed_modifiers was that it contained
  * all modifiers that might affect the translation of the key;
  * this allowed accelerators to be stored with irrelevant consumed
- * modifiers, by doing:
- * |[<!-- language="C" -->
- * // XXX Don’t do this XXX
+ * modifiers, by doing:</para>
+ * <informalexample><programlisting>
+ * &sol;* XXX Don't do this XXX *&sol;
  * if (keyval == accel_keyval &&
- *     (event->state & ~consumed & ALL_ACCELS_MASK) == (accel_mods & ~consumed))
- *   // Accelerator was pressed
- * ]|
- *
+ *     (event->state &amp; ~consumed &amp; ALL_ACCELS_MASK) == (accel_mods &amp; ~consumed))
+ *   &sol;* Accelerator was pressed *&sol;
+ * </programlisting></informalexample>
+ * <para>
  * However, this did not work if multi-modifier combinations were
- * used in the keymap, since, for instance, `<Control>` would be
- * masked out even if only `<Control><Alt>` was used in the keymap.
- * To support this usage as well as well as possible, all single
- * modifier combinations that could affect the key for any combination
- * of modifiers will be returned in @consumed_modifiers; multi-modifier
- * combinations are returned only when actually found in @state. When
- * you store accelerators, you should always store them with consumed
- * modifiers removed. Store `<Control>plus`, not `<Control><Shift>plus`,
+ * used in the keymap, since, for instance, <literal>&lt;Control&gt;</literal>
+ * would be masked out even if only <literal>&lt;Control&gt;&lt;Alt&gt;</literal>
+ * was used in the keymap. To support this usage as well as well as
+ * possible, all <emphasis>single modifier</emphasis> combinations
+ * that could affect the key for any combination of modifiers will
+ * be returned in @consumed_modifiers; multi-modifier combinations
+ * are returned only when actually found in @state. When you store
+ * accelerators, you should always store them with consumed modifiers
+ * removed. Store <literal>&lt;Control&gt;plus</literal>,
+ * not <literal>&lt;Control&gt;&lt;Shift&gt;plus</literal>,
+ * </para></note>
  *
- * Returns: %TRUE if there was a keyval bound to the keycode/state/group
+ * Return value: %TRUE if there was a keyval bound to the keycode/state/group
  **/
 gboolean
 gdk_keymap_translate_keyboard_state (GdkKeymap       *keymap,
@@ -615,7 +620,7 @@ gdk_keymap_add_virtual_modifiers (GdkKeymap       *keymap,
  * This function is useful when matching key events against
  * accelerators.
  *
- * Returns: %FALSE if two virtual modifiers were mapped to the
+ * Returns: %TRUE if no virtual modifiers were mapped to the
  *     same non-virtual modifier. Note that %FALSE is also returned
  *     if a virtual modifier is mapped to a non-virtual modifier that
  *     was already set in @state.
@@ -655,10 +660,6 @@ gdk_keymap_real_get_modifier_mask (GdkKeymap         *keymap,
     case GDK_MODIFIER_INTENT_SHIFT_GROUP:
       return 0;
 
-    case GDK_MODIFIER_INTENT_DEFAULT_MOD_MASK:
-      return (GDK_SHIFT_MASK   | GDK_CONTROL_MASK | GDK_MOD1_MASK    |
-	      GDK_SUPER_MASK   | GDK_HYPER_MASK   | GDK_META_MASK);
-
     default:
       g_return_val_if_reached (0);
     }
@@ -669,7 +670,7 @@ gdk_keymap_real_get_modifier_mask (GdkKeymap         *keymap,
  * @keymap: a #GdkKeymap
  * @intent: the use case for the modifier mask
  *
- * Returns the modifier mask the @keymap’s windowing system backend
+ * Returns the modifier mask the @keymap's windowing system backend
  * uses for a particular purpose.
  *
  * Note that this function always returns real hardware modifiers, not
@@ -692,7 +693,6 @@ gdk_keymap_get_modifier_mask (GdkKeymap         *keymap,
   return GDK_KEYMAP_GET_CLASS (keymap)->get_modifier_mask (keymap, intent);
 }
 
-#include "gdkkeynames.c"
 
 /**
  * gdk_keyval_name:
@@ -701,17 +701,20 @@ gdk_keymap_get_modifier_mask (GdkKeymap         *keymap,
  * Converts a key value into a symbolic name.
  *
  * The names are the same as those in the
- * `gdk/gdkkeysyms.h` header file
- * but without the leading “GDK_KEY_”.
+ * <filename>&lt;gdk/gdkkeysyms.h&gt;</filename> header file
+ * but without the leading "GDK_KEY_".
  *
- * Returns: (nullable) (transfer none): a string containing the name
- *     of the key, or %NULL if @keyval is not a valid key. The string
- *     should not be modified.
+ * Return value: (transfer none): a string containing the name of the key,
+ *     or %NULL if @keyval is not a valid key. The string should not be
+ *     modified.
  */
 gchar *
 gdk_keyval_name (guint keyval)
 {
-  return _gdk_keyval_name (keyval);
+  GdkDisplayManager *manager = gdk_display_manager_get ();
+
+  return GDK_DISPLAY_MANAGER_GET_CLASS (manager)->get_keyval_name (manager,
+                                                                   keyval);
 }
 
 /**
@@ -721,8 +724,8 @@ gdk_keyval_name (guint keyval)
  * Converts a key name to a key value.
  *
  * The names are the same as those in the
- * `gdk/gdkkeysyms.h` header file
- * but without the leading “GDK_KEY_”.
+ * <filename>&lt;gdk/gdkkeysyms.h&gt;</filename> header file
+ * but without the leading "GDK_KEY_".
  *
  * Returns: the corresponding key value, or %GDK_KEY_VoidSymbol
  *     if the key name is not a valid key
@@ -730,27 +733,20 @@ gdk_keyval_name (guint keyval)
 guint
 gdk_keyval_from_name (const gchar *keyval_name)
 {
-  return _gdk_keyval_from_name (keyval_name);
+  GdkDisplayManager *manager = gdk_display_manager_get ();
+
+  return GDK_DISPLAY_MANAGER_GET_CLASS (manager)->lookup_keyval (manager,
+                                                                 keyval_name);
 }
 
-/**
- * gdk_keyval_convert_case:
- * @symbol: a keyval
- * @lower: (out): return location for lowercase version of @symbol
- * @upper: (out): return location for uppercase version of @symbol
- *
- * Obtains the upper- and lower-case versions of the keyval @symbol.
- * Examples of keyvals are #GDK_KEY_a, #GDK_KEY_Enter, #GDK_KEY_F1, etc.
- */
 void
-gdk_keyval_convert_case (guint symbol,
-                         guint *lower,
-                         guint *upper)
+_gdk_display_manager_real_keyval_convert_case (GdkDisplayManager *manager,
+                                               guint              symbol,
+                                               guint             *lower,
+                                               guint             *upper)
 {
-  guint xlower, xupper;
-
-  xlower = symbol;
-  xupper = symbol;
+  guint xlower = symbol;
+  guint xupper = symbol;
 
   /* Check for directly encoded 24-bit UCS characters: */
   if ((symbol & 0xff000000) == 0x01000000)
